==> talent-ui-bootstrap-1.0.3.tgz: package/lib/configure-store.js <==
var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import { createStore, applyMiddleware } from "redux";
import appConfig from "app-config";
var emptyArray = [];
import composeReducer from "./compose-reducers";

var getMiddlewareConfig = function getMiddlewareConfig(config) {
    var middlewares = [],
        callback = void 0,
        initialState = void 0;
    if (Object.prototype.toString.call(config) === "[object Array]") {
        middlewares = config;
    } else if ((typeof config === "undefined" ? "undefined" : _typeof(config)) === "object") {
        middlewares = config["middlewares"] || middlewares;
        callback = config["callback"];
        initialState = config["initialState"];
    }
    return { middlewares: middlewares, callback: callback, initialState: initialState };
};

var configureStore = function configureStore(config) {
    return function (reducer) {
        var _getMiddlewareConfig = getMiddlewareConfig(config),
            middlewares = _getMiddlewareConfig.middlewares,
            callback = _getMiddlewareConfig.callback,
            initialState = _getMiddlewareConfig.initialState;

        var store = createStore(composeReducer(reducer), initialState, applyMiddleware.apply(undefined, _toConsumableArray(middlewares)));
        callback && callback(store);
        return store;
    };
};

export default configureStore(appConfig);

==> talent-ui-bootstrap-1.0.9.tgz: package/lib/configure-store.js <==
var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import { createStore, applyMiddleware } from "redux";
import appConfig from "app-config";
var emptyArray = [];
import composeReducer from "./compose-reducers";

var getMiddlewareConfig = function getMiddlewareConfig() {
    var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var middlewares = [],
        callback = void 0,
        initialState = void 0;
    if (Object.prototype.toString.call(config) === "[object Array]") {
        middlewares = config;
    } else if ((typeof config === "undefined" ? "undefined" : _typeof(config)) === "object") {
        middlewares = config["middlewares"] || middlewares;
        callback = config["callback"];
        initialState = config["initialState"];
    }
    return { middlewares: middlewares, callback: callback, initialState: initialState };
};

var configureStore = function configureStore(config) {
    return function (reducer) {
        var _getMiddlewareConfig = getMiddlewareConfig(config),
            middlewares = _getMiddlewareConfig.middlewares,
            callback = _getMiddlewareConfig.callback,
            initialState = _getMiddlewareConfig.initialState;

        var store = createStore(composeReducer(reducer), initialState, applyMiddleware.apply(undefined, _toConsumableArray(middlewares)));
        callback && callback(store);
        return store;
    };
};

export default configureStore(appConfig);
